@@ -46,15 +46,17 @@ class Constructor:
 
 
 class ConstructorError(Exception):
-    def __init__(self, element, args, kwargs):
+    def __init__(self, element, args, kwargs, e):
         self.cls = type(element).__name__
         self.name = element.name
         self.args = args
         self.kwargs = kwargs
+        self.e = e
 
     def __str__(self):
         return f"Unable to construct {self.cls} '{self.name}' with args:{self.args} and " \
-               f"kwargs:{self.kwargs}"
+               f"kwargs:{self.kwargs}.\nFollowing exception occurred:\n" \
+               f"{self.e.__class__.__name__}: {self.e}"
 
 
 # mb: add meta for auto detecting this class as YAP-builder
